==> ejc-salary-impl-3.0.0-20241017.065649-32-sources.jar: com/ejianc/business/salary/bean/JspayableAdjustEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_adjust")
public class JspayableAdjustEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_detail_id")
    private Long jspayableDetailId; // 所属明细id
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码
    @TableField(value="ac_set")
    private String acSet; // 账套
    @TableField(value="ac_set_code")
    private String acSetCode; // 账套编码
    @TableField(value="person_endowment_mny")
    private BigDecimal personEndowmentMny; // 个人养老金额
    @TableField(value="person_medical_mny")
    private BigDecimal personMedicalMny; // 个人医疗金额
    @TableField(value="person_unemployment_mny")
    private BigDecimal personUnemploymentMny; // 个人失业金额
    @TableField(value="person_house_mny")
    private BigDecimal personHouseMny; // 个人公积金
    @TableField(value="company_endowment_mny")
    private BigDecimal companyEndowmentMny; // 公司养老金额
    @TableField(value="company_medical_mny")
    private BigDecimal companyMedicalMny; // 公司医疗金额
    @TableField(value="company_unemployment_mny")
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    @TableField(value="company_birth_mny")
    private BigDecimal companyBirthMny; // 公司生育金额
    @TableField(value="company_injure_mny")
    private BigDecimal companyInjureMny; // 公司工伤金额
    @TableField(value="company_house_mny")
    private BigDecimal companyHouseMny; // 公司公积金
    @TableField(value="scale")
    private BigDecimal scale; // 占总额比例
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="period")
    private Date period; // 期间 应发工资计算的 月份
    @TableField(value="is_default")
    private String isDefault; // 是否默认单位 1是,2-否


    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }

    public String getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(String isDefault) {
        this.isDefault = isDefault;
    }
}

==> ejc-salary-impl-3.0.0-20241129.081012-74-sources.jar: com/ejianc/business/salary/bean/JspayableAdjustEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_adjust")
public class JspayableAdjustEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_detail_id")
    private Long jspayableDetailId; // 所属明细id
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码
    @TableField(value="ac_set")
    private String acSet; // 账套
    @TableField(value="ac_set_code")
    private String acSetCode; // 账套编码
    @TableField(value="person_endowment_mny")
    private BigDecimal personEndowmentMny; // 个人养老金额
    @TableField(value="person_medical_mny")
    private BigDecimal personMedicalMny; // 个人医疗金额
    @TableField(value="person_unemployment_mny")
    private BigDecimal personUnemploymentMny; // 个人失业金额
    @TableField(value="person_house_mny")
    private BigDecimal personHouseMny; // 个人公积金
    @TableField(value="company_endowment_mny")
    private BigDecimal companyEndowmentMny; // 公司养老金额
    @TableField(value="company_medical_mny")
    private BigDecimal companyMedicalMny; // 公司医疗金额
    @TableField(value="company_unemployment_mny")
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    @TableField(value="company_birth_mny")
    private BigDecimal companyBirthMny; // 公司生育金额
    @TableField(value="company_injure_mny")
    private BigDecimal companyInjureMny; // 公司工伤金额
    @TableField(value="company_house_mny")
    private BigDecimal companyHouseMny; // 公司公积金
    @TableField(value="scale")
    private BigDecimal scale; // 占总额比例
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="period")
    private Date period; // 期间 应发工资计算的 月份
    @TableField(value="is_default")
    private String isDefault; // 是否默认单位 1是,2-否
    @TableField(value="company_id")
    private Long companyId; // 汇总单所属公司id
    @TableField(value="company_name")
    private String companyName; // 汇总单所属公司

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }


    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }

    public String getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(String isDefault) {
        this.isDefault = isDefault;
    }
}
